import React from 'jsx-dom'; // necessary for react to work
import { Actions, GetAccountsReply } from '../background/messages';
import { Event, ClientEvents } from './events';
import * as background from './background';
import { Account } from '../landsbankinn/models';
import $ from 'cash-dom';

interface AccountListProps {
    accounts: Array<Account>;
}

function AccountList(props: AccountListProps) {
    const selectAllHandler = () => {
        const checked = $('#check-all').prop('checked');
        $('#account-export-list input[type="checkbox"]').prop('checked', checked);
    };

    const accountList = props.accounts.map(acct =>
        <li>
            <input id="export-{acct.acountNumber}" type="checkbox" />
            &nbsp;
            <label htmlFor="export-{acct.acountNumber}">
                {acct.accountNumber} - {acct.name}
            </label>
        </li>
    );

    return (
        <div id="account-export-list">
            <ul>
                <li>
                    <input id="check-all" type="checkbox" onClick={selectAllHandler} />
                    &nbsp;
                    <label htmlFor="check-all">Select All</label>
                </li>
                {accountList}
            </ul>
        </div>
    );
}

window.addEventListener('DOMContentLoaded', async () => {
    ClientEvents.on(Event.StatePopulated, async () => {
        const response = await background.getAccounts();

        if (response.error == null) {
            const exportDiv = (
                <div id="account-export" class="content-box fill shadow ui-form">
                    <h2>Download Transaction Statements</h2>
                    <p>
                        Here, you can export statements from one or more of your accounts
                        over a specified date range.
                    </p>

                    <AccountList accounts={response.accounts} />
                </div>
            );

            const contentDiv = document.querySelector(
                'div[class="table-data content-box fill shadow"]'
            );
            contentDiv?.prepend(exportDiv);
        }
    });
});
